<?php
/**
 * Theme: Nextawards
 *
 * Theme Functions, includes, etc.
 *
 * @package nextawards
 */


/* ------------------------------------------------------------------------- *
 *  Base functionality
/* ------------------------------------------------------------------------- */


	// Content width
	if ( !isset( $content_width ) ) { $content_width = 720; }


/*  Theme setup
/* ------------------------------------ */
if ( ! function_exists( 'nextawards_setup' ) ) {

	function nextawards_setup() {

		$nextawards_bg_color_defaults = array(
			'default-color'          => '#E4E4E4',
		);
		add_theme_support( 'custom-background', $nextawards_bg_color_defaults );

		// add title
		add_theme_support( "title-tag" );

		// logo
		$nextawards_logo_defaults = array(
			'height'               => 100,
			'width'                => 400,
			'flex-height'          => true,
			'flex-width'           => true,
			'header-text'          => array( 'site-title', 'site-description' ),
			'unlink-homepage-logo' => true, 
		);
		add_theme_support( 'custom-logo', $nextawards_logo_defaults );

		// Enable automatic feed links
		add_theme_support( 'automatic-feed-links' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// responsive embeds css classes
		add_theme_support( "responsive-embeds" );

		// html5
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption', 'style', 'script' ) );

		// add default Gutenberg block styles 
		add_theme_support( 'wp-block-styles' );

		// Enable featured image
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'align-wide' );

		// Thumbnail sizes
		add_image_size( 'nextawards_single', 800, 493, true ); //(cropped)
		add_image_size( 'nextawards_big', 1400, 928, true ); 	//(cropped)

		// Custom menu areas
		register_nav_menus( array(
			'header' => esc_html__( 'Header', 'nextawards' ),
			'quickmenu' => esc_html__( 'Quick Menu', 'nextawards' )
		) );

		// Load theme languages
		load_theme_textdomain( 'nextawards', get_template_directory().'/languages' );

		// Adds support for editor color palette.
		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => __( 'Light gray', 'nextawards' ),
				'slug'  => 'light-gray',
				'color'	=> '#f5f5f5',
			),
			array(
				'name'  => __( 'Medium gray', 'nextawards' ),
				'slug'  => 'medium-gray',
				'color' => '#999',
			),
			array(
				'name'  => __( 'Dark gray', 'nextawards' ),
				'slug'  => 'dark-gray',
				'color' => '#333',
			),
			array(
				'name'  => __( 'Link Color', 'nextawards' ),
				'slug'  => 'link-color',
				'color' => esc_attr(get_theme_mod( 'nextawards_link_color', '#048ea0')),
			),
			array(
				'name'  => __( 'Link Color Hover', 'nextawards' ),
				'slug'  => 'link-color-hover',
				'color' => esc_attr(get_theme_mod( 'nextawards_link_color_hover', '#105862')),
			),
		));

		// block style
		register_block_style(
				'core/quote',
				array(
						'name'         => 'blue-quote',
						'label'        => __( 'Blue Quote', 'nextawards' ),
						'is_default'   => true,
						'inline_style' => '.wp-block-quote.is-style-blue-quote { color: blue; }',
				)
		);
	

		// block pattern
		register_block_pattern(
			'nextawards/nextawards-button-pattern',
			array(
					'title'       => __( 'Two buttons', 'nextawards' ),
					'description' => _x( 'Two horizontal buttons, the left button is filled in, and the right button is outlined.', 'Block pattern description', 'nextawards' ),
					'content'     => "<!-- wp:buttons {\"align\":\"center\"} -->\n<div class=\"wp-block-buttons aligncenter\"><!-- wp:button {\"backgroundColor\":\"very-dark-gray\",\"borderRadius\":0} -->\n<div class=\"wp-block-button\"><a class=\"wp-block-button__link has-background has-very-dark-gray-background-color no-border-radius\">" . esc_html__( 'Button One', 'nextawards' ) . "</a></div>\n<!-- /wp:button -->\n\n<!-- wp:button {\"textColor\":\"very-dark-gray\",\"borderRadius\":0,\"className\":\"is-style-outline\"} -->\n<div class=\"wp-block-button is-style-outline\"><a class=\"wp-block-button__link has-text-color has-very-dark-gray-color no-border-radius\">" . esc_html__( 'Button Two', 'nextawards' ) . "</a></div>\n<!-- /wp:button --></div>\n<!-- /wp:buttons -->",
			)
		);

	}

}
add_action( 'after_setup_theme', 'nextawards_setup' );


/*  Enqueue javascript
/* ------------------------------------ */
if ( ! function_exists( 'nextawards_scripts' ) ) {

	function nextawards_scripts() {

		// all script
		wp_enqueue_script( 'nextawards-script', get_template_directory_uri() . '/js/script.js', array(),'', true );

		if ( is_singular() && get_option( 'thread_comments' ) )	{ wp_enqueue_script( 'comment-reply' ); }
	}

}
add_action( 'wp_enqueue_scripts', 'nextawards_scripts' );


/*  Enqueue css
/* ------------------------------------ */
if ( ! function_exists( 'nextawards_styles' ) ) {

	function nextawards_styles() {
		wp_enqueue_style( 'nextawards-google-font','//fonts.googleapis.com/css?family='.esc_attr(get_theme_mod( "nextawards_google_font", "Barlow")).':'.esc_attr(get_theme_mod( "nextawards_google_font_weight", "300,400,700")));
		wp_enqueue_style( 'nextawards', get_template_directory_uri().'/style.css');

	}

}
add_action( 'wp_enqueue_scripts', 'nextawards_styles' );

/*  Enqueue google font backend css
/* ------------------------------------ */
if ( ! function_exists( 'nextawards_admin_google_font' ) ) {

	function nextawards_admin_google_font() {
		wp_register_style( 'nextawards-admin-google-font', '//fonts.googleapis.com/css?family='.esc_attr(get_theme_mod( "nextawards_google_font", "Barlow")).':'.esc_attr(get_theme_mod( "nextawards_google_font_weight", "300,400,700")));
		wp_enqueue_style( 'nextawards-admin-google-font' );
	}
}

add_action( 'admin_enqueue_scripts', 'nextawards_admin_google_font');


/*  Register sidebars
/* ------------------------------------ */
if ( ! function_exists( 'nextawards_sidebars' ) ) {

	function nextawards_sidebars()	{
		register_sidebar(array( 'name' => esc_html__( 'Footer', 'nextawards' ),'id' => 'footer','description' => esc_html__( 'Normal full width sidebar.', 'nextawards' ), 'before_widget' => '<div id="%1$s" class="col-33 mb-3 %2$s">','after_widget' => '</div>','before_title' => '<h3>','after_title' => '</h3>'));
	}

}
add_action( 'widgets_init', 'nextawards_sidebars' );



/*  Register editor stylesheet for the theme.
/* ------------------------------------ */
function nextawards_add_editor_styles() {
	add_editor_style( 'custom-editor-style.css' );
}
add_action( 'admin_init', 'nextawards_add_editor_styles' );


/* Customizer Settings
/* ------------------------------------ */
function nextawards_customize_register( $wp_customize ) {
	
	/* Typography Section */
	$wp_customize->add_section( 'nextawards_typography' , array(
    'title'      => __( 'Typography', 'nextawards' ),
    'priority'   => 30,
	));

	/* Font Name */
	$wp_customize->add_setting( 'nextawards_google_font' , array(
    'default'   => 'Barlow',
    'transport' => 'refresh',
		'sanitize_callback' => 'nextawards_sanitize_callback_function',
	));

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'nextawards_google_font_control', array(
		'label'      => __( 'Google Font (ex. Roboto )', 'nextawards' ),
		'section'    => 'nextawards_typography',
		'settings'   => 'nextawards_google_font',
		'type'   => 'text'			
	)) );

	/* Font Weights */
	$wp_customize->add_setting( 'nextawards_google_font_weight' , array(
    'default'   => '300,400,700',
    'transport' => 'refresh',
		'sanitize_callback' => 'nextawards_sanitize_callback_function',
	));

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'nextawards_google_font_weight_control', array(
		'label'      => __( 'Font Weight (ex. 300,400,700 )', 'nextawards' ),
		'section'    => 'nextawards_typography',
		'settings'   => 'nextawards_google_font_weight',
		'type'   => 'text'			
	)));

	/* Link color */
	$wp_customize->add_setting( 'nextawards_link_color' , array(
    'default'   => '#048ea0',
    'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
	));

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nextawards_link_color_control', array(
		'label'      => __( 'Link Color', 'nextawards' ),
		'section'    => 'colors',
		'settings'   => 'nextawards_link_color',
	)));


	/* Link color hover */
	$wp_customize->add_setting( 'nextawards_link_color_hover' , array(
    'default'   => '#105862',
    'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
	));

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nextawards_link_color_hover_control', array(
		'label'      => __( 'Link Color Hover', 'nextawards' ),
		'section'    => 'colors',
		'settings'   => 'nextawards_link_color_hover',
	)));


	/* Sanitize function */
	function nextawards_sanitize_callback_function( $nextawards_input_to_sanitize ) {
    
		return sanitize_text_field( $nextawards_input_to_sanitize );
	
	}

	
}
add_action( 'customize_register', 'nextawards_customize_register' );

/* Customizer CSS Front-end */
/* ------------------------------------ */
function nextawards_customize_css(){

	$nextawards_bg_color = get_background_color();
	echo '<style type="text/css">';
	echo ':root { --site-bg: #'.$nextawards_bg_color.'; --link-color: '.esc_attr(get_theme_mod( 'nextawards_link_color', '#048ea0')).'; --link-color-hover: '.esc_attr(get_theme_mod( 'nextawards_link_color_hover', '#105862')).'; }';
	echo 'body{font-family: '.esc_attr(get_theme_mod( 'nextawards_google_font', 'Barlow')).'}';
	echo '.wp-block-button__link{background-color: '.esc_attr(get_theme_mod( 'nextawards_link_color', '#048ea0')).'}';
	echo '.wp-block-button__link:hover{background-color: '.esc_attr(get_theme_mod( 'nextawards_link_color_hover', '#105862')).'}';
	echo '</style>';

}
add_action( 'wp_head', 'nextawards_customize_css');

/* Customizer CSS back-end */
/* ------------------------------------ */
function nextawards_customize_css_backend() {

	$nextawards_bg_color = get_background_color();
	echo '<style type="text/css">';
	echo '.block-editor__container .editor-styles-wrapper .wp-block-post-title,
				.block-editor__container .editor-styles-wrapper .wp-block-heading,
				.block-editor__container .editor-styles-wrapper .wp-block { font-family: '.esc_attr(get_theme_mod( 'nextawards_google_font', 'Barlow')).';}';	
	echo '.block-editor__container .editor-styles-wrapper{background: #'.$nextawards_bg_color.'}';
	echo '.block-editor__container .editor-styles-wrapper .wp-block-button__link{background-color: '.esc_attr(get_theme_mod( 'nextawards_link_color', '#048ea0')).'}';
	echo '</style>';
	
}
add_action( 'admin_head', 'nextawards_customize_css_backend' );

?>
